==> VirtualBoxSDK-6.1.16-140961.zip: org/virtualbox_6_1/jaxws/IRecordingScreenSettingsSetVideoRateControlMode.java <==

package org.virtualbox_6_1.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="videoRateControlMode" type="{http://www.virtualbox.org/}RecordingVideoRateControlMode"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "videoRateControlMode"
})
@XmlRootElement(name = "IRecordingScreenSettings_setVideoRateControlMode")
public class IRecordingScreenSettingsSetVideoRateControlMode {

    @XmlElement(required = true)
    protected String _this;
    @XmlElement(required = true)
    protected RecordingVideoRateControlMode videoRateControlMode;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the videoRateControlMode property.
     * 
     * @return
     *     possible object is
     *     {@link RecordingVideoRateControlMode }
     *     
     */
    public RecordingVideoRateControlMode getVideoRateControlMode() {
        return videoRateControlMode;
    }

    /**
     * Sets the value of the videoRateControlMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecordingVideoRateControlMode }
     *     
     */
    public void setVideoRateControlMode(RecordingVideoRateControlMode value) {
        this.videoRateControlMode = value;
    }

}

==> VirtualBoxSDK-7.0.10-158379.zip: org/virtualbox_7_0/jaxws/IRecordingScreenSettingsSetVideoRateControlMode.java <==

package org.virtualbox_7_0.jaxws;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="_this" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="videoRateControlMode" type="{http://www.virtualbox.org/}RecordingRateControlMode"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "_this",
    "videoRateControlMode"
})
@XmlRootElement(name = "IRecordingScreenSettings_setVideoRateControlMode")
public class IRecordingScreenSettingsSetVideoRateControlMode {

    @XmlElement(required = true)
    protected String _this;
    @XmlElement(required = true)
    protected RecordingRateControlMode videoRateControlMode;

    /**
     * Gets the value of the this property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThis() {
        return _this;
    }

    /**
     * Sets the value of the this property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThis(String value) {
        this._this = value;
    }

    /**
     * Gets the value of the videoRateControlMode property.
     * 
     * @return
     *     possible object is
     *     {@link RecordingRateControlMode }
     *     
     */
    public RecordingRateControlMode getVideoRateControlMode() {
        return videoRateControlMode;
    }

    /**
     * Sets the value of the videoRateControlMode property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecordingRateControlMode }
     *     
     */
    public void setVideoRateControlMode(RecordingRateControlMode value) {
        this.videoRateControlMode = value;
    }

}
